# import de sqlalchemy
from sqlalchemy import Column, Boolean, String, Integer, Numeric
from sqlalchemy.orm import relationship, backref
from sqlalchemy.ext.declarative import declarative_base
from sqlalchemy import create_engine
from sqlalchemy.orm import sessionmaker

# Declaration de la classe de déclaration des modèles de BDD
Base = declarative_base() 

# Création d'une classe selon la syntaxe objet SQLAlchemy
class Form(Base):
    __tablename__ = 'baillard_anthony'
    id = Column(Integer, primary_key=True)
    title = Column('title', String(64))
    message = Column('message', String)
    gender = Column('gender', Boolean)
    like = Column('like', Integer)

    # methode magique pour print()
    def __str__(self):
        return "{} | {}".format(self.title, self.message)

# Création du moteur de BDD (MySQL en l'occurrence)
# Noter l'utilisation du protocole mysql+mysqlconnector pour
# que python utilise la librairie  mysql-connector et non
# un client binaire MySQL qui devrait être installé sur votre
# ordinateur
engine = create_engine('mysql+mysqlconnector://login:password@host/db')

# Création d'une session pour utiliser la connexion
# (équivalent d'un curseur avec la lib mysql-connector-python)
session = sessionmaker()
session.configure(bind=engine)
s = session()

# Commande pour créer la base de données
Base.metadata.create_all(engine)

# Equivalent de "SELECT *"
print("---- print ----")
for p in s.query(Form).all():
    print(p)

# Insertion, équivalent de "INSERT INTO"
form = Form(title="depuis SQLAlchemy", message="message",
            gender=False, like=2)
s.add(form)
s.commit()

# Equivalent de SELECT * WHERE title='depuis SQLAlchemy'
print("---- print ----")
for p in s.query(Form).filter_by(title="depuis SQLAlchemy"):
    print(p)

# Equivalent de "UPDATE WHERE 'id'="
form.message = "updated"
s.commit()

# Equivalent de SELECT * WHERE title LIKE '% SQLAlchemy%'
print("---- print ----")
for p in s.query(Form).filter(Form.title.like("SQLAlchemy")):
    print(p)

# Equivalent de "DELETE FROM . WHERE title='depuis SQLAlchemy'"
s.query(Form).filter_by(title="depuis SQLAlchemy").delete()
s.commit()

# Equivalent de "SELECT *"
print("---- print ----")
for p in s.query(Form).all():
    print(p)
